@@ -1,13 +1,10 @@
 #!/usr/bin/python3
 # -*- Mode: Python; indent-tabs-mode: nil; tab-width: 4; coding: utf-8 -*-
 
-import apt
 import apt_pkg
-import hashlib
 import mock
 import os
 import unittest
-import shutil
 import tempfile
 import json
 
@@ -172,76 +169,6 @@ def make_mock_pkg(name, is_installed, candidate_rec=""):
     return mock_pkg
 
 
-class TestPatches(unittest.TestCase):
-
-    orig_chdir = ''
-
-    def setUp(self):
-        # To patch, we need to be in the same directory as the patched files
-        self.orig_chdir = os.getcwd()
-        os.chdir(CURDIR)
-
-    def tearDown(self):
-        os.chdir(self.orig_chdir)
-
-    def _verify_result_checksums(self):
-        """ helper for test_patch to verify that we get the expected result """
-        # simple case is foo
-        patchdir = CURDIR + "/patchdir/"
-        with open(patchdir + "foo") as f:
-            self.assertFalse("Hello" in f.read())
-        with open(patchdir + "foo_orig") as f:
-            self.assertTrue("Hello" in f.read())
-        md5 = hashlib.md5()
-        with open(patchdir + "foo", "rb") as patch:
-            md5.update(patch.read())
-        self.assertEqual(md5.hexdigest(), "52f83ff6877e42f613bcd2444c22528c")
-        # more complex example fstab
-        md5 = hashlib.md5()
-        with open(patchdir + "fstab", "rb") as patch:
-            md5.update(patch.read())
-        self.assertEqual(md5.hexdigest(), "c56d2d038afb651920c83106ec8dfd09")
-        # most complex example
-        md5 = hashlib.md5()
-        with open(patchdir + "pycompile", "rb") as patch:
-            md5.update(patch.read())
-        self.assertEqual(md5.hexdigest(), "97c07a02e5951cf68cb3f86534f6f917")
-        # with ".\n"
-        md5 = hashlib.md5()
-        with open(patchdir + "dotdot", "rb") as patch:
-            md5.update(patch.read())
-        self.assertEqual(md5.hexdigest(), "cddc4be46bedd91db15ddb9f7ddfa804")
-        # test that incorrect md5sum after patching rejects the patch
-        with open(patchdir + "fail") as f1, open(patchdir + "fail_orig") as f2:
-            self.assertEqual(f1.read(),
-                             f2.read())
-
-    def test_patch(self):
-        q = DistUpgradeQuirks(MockController(), MockConfig)
-        # create patch environment
-        patchdir = CURDIR + "/patchdir/"
-        shutil.copy(patchdir + "foo_orig", patchdir + "foo")
-        shutil.copy(patchdir + "fstab_orig", patchdir + "fstab")
-        shutil.copy(patchdir + "pycompile_orig", patchdir + "pycompile")
-        shutil.copy(patchdir + "dotdot_orig", patchdir + "dotdot")
-        shutil.copy(patchdir + "fail_orig", patchdir + "fail")
-        # apply patches
-        q._applyPatches(patchdir=patchdir)
-        self._verify_result_checksums()
-        # now apply patches again and ensure we don't patch twice
-        q._applyPatches(patchdir=patchdir)
-        self._verify_result_checksums()
-
-    def test_patch_lowlevel(self):
-        # test lowlevel too
-        from DistUpgrade.DistUpgradePatcher import patch, PatchError
-        self.assertRaises(PatchError, patch, CURDIR + "/patchdir/fail",
-                          CURDIR + "/patchdir/patchdir_fail."
-                          "ed04abbc6ee688ee7908c9dbb4b9e0a2."
-                          "deadbeefdeadbeefdeadbeff",
-                          "deadbeefdeadbeefdeadbeff")
-
-
 class TestQuirks(unittest.TestCase):
 
     orig_recommends = ''
@@ -273,39 +200,6 @@ class TestQuirks(unittest.TestCase):
         q.ensure_recommends_are_installed_on_desktops()
         self.assertTrue(apt_pkg.config.find_b("APT::Install-Recommends"))
 
-    def test_parse_from_modaliases_header(self):
-        pkgrec = {
-            "Package": "foo",
-            "Modaliases": "modules1(pci:v00001002d00006700sv*sd*bc03sc*i*, "
-                          "pci:v00001002d00006701sv*sd*bc03sc*i*), "
-                          "module2(pci:v00001002d00006702sv*sd*bc03sc*i*, "
-                          "pci:v00001001d00006702sv*sd*bc03sc*i*)"
-        }
-        controller = mock.Mock()
-        config = mock.Mock()
-        q = DistUpgradeQuirks(controller, config)
-        self.assertEqual(q._parse_modaliases_from_pkg_header({}), [])
-        self.assertEqual(q._parse_modaliases_from_pkg_header(pkgrec),
-                         [("modules1",
-                           ["pci:v00001002d00006700sv*sd*bc03sc*i*",
-                            "pci:v00001002d00006701sv*sd*bc03sc*i*"]),
-                          ("module2",
-                           ["pci:v00001002d00006702sv*sd*bc03sc*i*",
-                            "pci:v00001001d00006702sv*sd*bc03sc*i*"])])
-
-    def disabled__as_fglrx_is_gone_testFglrx(self):
-        mock_lspci_good = set(['1002:9990'])
-        mock_lspci_bad = set(['8086:ac56'])
-        config = mock.Mock()
-        cache = apt.Cache()
-        controller = mock.Mock()
-        controller.cache = cache
-        q = DistUpgradeQuirks(controller, config)
-        if q.arch not in ['i386', 'amd64']:
-            return self.skipTest("Not on an arch with fglrx package")
-        self.assertTrue(q._supportInModaliases("fglrx", mock_lspci_good))
-        self.assertFalse(q._supportInModaliases("fglrx", mock_lspci_bad))
-
     def test_screensaver_poke(self):
         # fake nothing is installed
         empty_status = tempfile.NamedTemporaryFile()
@@ -436,16 +330,6 @@ class TestQuirks(unittest.TestCase):
         self.assertFalse(len(mock_question.mock_calls))
         self.assertFalse(len(mock_controller.abort.mock_calls))
 
-    @mock.patch('os.path.exists')
-    def test_aufs_fail(self, mock_exists):
-        mock_exists.return_value = True
-        mock_controller = mock.Mock()
-
-        q = DistUpgradeQuirks(mock_controller, mock.Mock())
-
-        q._test_and_fail_on_aufs()
-        self.assertTrue(len(mock_controller.abort.mock_calls))
-
     def test_replace_fkms_overlay_no_config(self):
         with tempfile.TemporaryDirectory() as boot_dir:
             mock_controller = mock.Mock()
@@ -601,205 +485,6 @@ max_framebuffers=2
             with open(os.path.join(boot_dir, 'config.txt')) as f:
                 self.assertTrue(f.read() == expected_config_txt)
 
-    def test_remove_uboot_no_config(self):
-        with tempfile.TemporaryDirectory() as boot_dir:
-            mock_controller = mock.Mock()
-            q = DistUpgradeQuirks(mock_controller, mock.Mock())
-            q._remove_uboot_on_rpi(boot_dir)
-
-            self.assertFalse(os.path.exists(os.path.join(
-                boot_dir, 'config.txt.distUpgrade')))
-
-    def test_remove_uboot_no_changes(self):
-        with tempfile.TemporaryDirectory() as boot_dir:
-            native_config = """\
-# This is a demo boot config with a comment at the start that should not
-# be removed
-
-[pi4]
-max_framebuffers=2
-
-[all]
-arm_64bit=1
-kernel=vmlinuz
-initramfs initrd.img followkernel
-
-# This is a user-added include that should not be merged
-include custom.txt
-"""
-            custom_config = """\
-# This is the custom included configuration file
-
-hdmi_group=1
-hdmi_mode=4
-"""
-            with open(os.path.join(boot_dir, 'config.txt'), 'w') as f:
-                f.write(native_config)
-            with open(os.path.join(boot_dir, 'custom.txt'), 'w') as f:
-                f.write(custom_config)
-
-            mock_controller = mock.Mock()
-            q = DistUpgradeQuirks(mock_controller, mock.Mock())
-            q._remove_uboot_on_rpi(boot_dir)
-
-            self.assertFalse(os.path.exists(os.path.join(
-                boot_dir, 'config.txt.distUpgrade')))
-            self.assertFalse(os.path.exists(os.path.join(
-                boot_dir, 'custom.txt.distUpgrade')))
-            with open(os.path.join(boot_dir, 'config.txt')) as f:
-                self.assertTrue(f.read() == native_config)
-            with open(os.path.join(boot_dir, 'custom.txt')) as f:
-                self.assertTrue(f.read() == custom_config)
-
-    def test_remove_uboot_with_changes(self):
-        with tempfile.TemporaryDirectory() as boot_dir:
-            config_txt = """\
-# This is a warning that you should not edit this file. The upgrade should
-# remove this comment
-
-[pi4]
-# This is a comment that should be included
-kernel=uboot_rpi_4.bin
-max_framebuffers=2
-
-[pi2]
-kernel=uboot_rpi_2.bin
-
-[pi3]
-kernel=uboot_rpi_3.bin
-
-[all]
-arm_64bit=1
-device_tree_address=0x3000000
-include syscfg.txt
-include usercfg.txt
-dtoverlay=vc4-fkms-v3d,cma-256
-include custom.txt
-"""
-            usercfg_txt = """\
-# Another chunk of warning text that should be skipped
-"""
-            syscfg_txt = """\
-# Yet more warnings to exclude
-dtparam=audio=on
-dtparam=spi=on
-enable_uart=1
-"""
-            custom_txt = """\
-# This is a user-added file that should be left alone by the upgrade
-[gpio4=1]
-kernel=custom
-"""
-            expected_config_txt = """\
-
-[pi4]
-# This is a comment that should be included
-# commented by do-release-upgrade (LP: #1936401)
-#kernel=uboot_rpi_4.bin
-max_framebuffers=2
-
-[pi2]
-# commented by do-release-upgrade (LP: #1936401)
-#kernel=uboot_rpi_2.bin
-
-[pi3]
-# commented by do-release-upgrade (LP: #1936401)
-#kernel=uboot_rpi_3.bin
-
-[all]
-# added by do-release-upgrade (LP: #1936401)
-kernel=vmlinuz
-initramfs initrd.img followkernel
-arm_64bit=1
-# commented by do-release-upgrade (LP: #1936401)
-#device_tree_address=0x3000000
-# merged from syscfg.txt by do-release-upgrade (LP: #1936401)
-dtparam=audio=on
-dtparam=spi=on
-enable_uart=1
-# merged from usercfg.txt by do-release-upgrade (LP: #1936401)
-dtoverlay=vc4-fkms-v3d,cma-256
-include custom.txt
-"""
-            with open(os.path.join(boot_dir, 'config.txt'), 'w') as f:
-                f.write(config_txt)
-            with open(os.path.join(boot_dir, 'syscfg.txt'), 'w') as f:
-                f.write(syscfg_txt)
-            with open(os.path.join(boot_dir, 'usercfg.txt'), 'w') as f:
-                f.write(usercfg_txt)
-            with open(os.path.join(boot_dir, 'custom.txt'), 'w') as f:
-                f.write(custom_txt)
-
-            mock_controller = mock.Mock()
-            q = DistUpgradeQuirks(mock_controller, mock.Mock())
-            q._remove_uboot_on_rpi(boot_dir)
-
-            self.assertTrue(os.path.exists(os.path.join(
-                boot_dir, 'config.txt.distUpgrade')))
-            self.assertTrue(os.path.exists(os.path.join(
-                boot_dir, 'syscfg.txt.distUpgrade')))
-            self.assertTrue(os.path.exists(os.path.join(
-                boot_dir, 'usercfg.txt.distUpgrade')))
-            self.assertTrue(os.path.exists(os.path.join(
-                boot_dir, 'config.txt')))
-            self.assertTrue(os.path.exists(os.path.join(
-                boot_dir, 'custom.txt')))
-            self.assertFalse(os.path.exists(os.path.join(
-                boot_dir, 'syscfg.txt')))
-            self.assertFalse(os.path.exists(os.path.join(
-                boot_dir, 'usercfg.txt')))
-            self.assertFalse(os.path.exists(os.path.join(
-                boot_dir, 'custom.txt.distUpgrade')))
-            with open(os.path.join(boot_dir, 'config.txt')) as f:
-                self.assertTrue(f.read() == expected_config_txt)
-            with open(os.path.join(boot_dir, 'custom.txt')) as f:
-                self.assertTrue(f.read() == custom_txt)
-
-    def test_remove_uboot_no_all_section(self):
-        with tempfile.TemporaryDirectory() as boot_dir:
-            config_txt = """\
-arm_64bit=1
-device_tree_address=0x3000000
-
-[pi4]
-# This is a comment that should be included
-kernel=uboot_rpi_4.bin
-max_framebuffers=2
-
-[pi3]
-kernel=uboot_rpi_3.bin
-"""
-            expected_config_txt = """\
-arm_64bit=1
-# commented by do-release-upgrade (LP: #1936401)
-#device_tree_address=0x3000000
-
-[pi4]
-# This is a comment that should be included
-# commented by do-release-upgrade (LP: #1936401)
-#kernel=uboot_rpi_4.bin
-max_framebuffers=2
-
-[pi3]
-# commented by do-release-upgrade (LP: #1936401)
-#kernel=uboot_rpi_3.bin
-# added by do-release-upgrade (LP: #1936401)
-[all]
-kernel=vmlinuz
-initramfs initrd.img followkernel
-"""
-            with open(os.path.join(boot_dir, 'config.txt'), 'w') as f:
-                f.write(config_txt)
-
-            mock_controller = mock.Mock()
-            q = DistUpgradeQuirks(mock_controller, mock.Mock())
-            q._remove_uboot_on_rpi(boot_dir)
-
-            self.assertTrue(os.path.exists(os.path.join(
-                boot_dir, 'config.txt.distUpgrade')))
-            with open(os.path.join(boot_dir, 'config.txt')) as f:
-                self.assertTrue(f.read() == expected_config_txt)
-
 
 class TestSnapQuirks(unittest.TestCase):
 
@@ -1022,66 +707,6 @@ class TestSnapQuirks(unittest.TestCase):
         # actual deb packages that will have to be removed during the upgrade
         self.assertEqual(controller.forced_obsoletes.append.call_count, 3)
 
-    @mock.patch("builtins.open", new_callable=mock.mock_open,
-                read_data="""\
-processor       : 0
-cpu             : POWER8 (raw), altivec supported
-clock           : 3491.000000MHz
-revision        : 2.0 (pvr 004d 0200)
-
-processor       : 1
-cpu             : POWER8 (raw), altivec supported
-clock           : 3491.000000MHz
-revision        : 2.0 (pvr 004d 0200)
-
-timebase        : 512000000
-platform        : PowerNV
-model           : 8001-22C
-machine         : PowerNV 8001-22C
-firmware        : OPAL
-MMU             : Hash
-""")
-    @mock.patch("DistUpgrade.DistUpgradeQuirks.get_arch",
-                return_value="ppc64el")
-    def test_power8_fail(self, arch, mock_file):
-        controller = mock.Mock()
-        config = mock.Mock()
-        q = DistUpgradeQuirks(controller, config)
-
-        q._test_and_fail_on_power8()
-        self.assertTrue(len(controller.abort.mock_calls))
-
-        mock_file.assert_called_with("/proc/cpuinfo")
-
-    def test_raspi_armhf_abort_upgrade(self):
-        for arch in ('armhf', 'arm64'):
-            with mock.patch(
-                'DistUpgrade.DistUpgradeQuirks.get_arch'
-            ) as mock_get_arch:
-
-                mock_get_arch.return_value = arch
-
-                controller = mock.Mock()
-                config = mock.Mock()
-                q = DistUpgradeQuirks(controller, config)
-                q.controller.fromDist = 'jammy'
-                q.controller.toDist = 'noble'
-                controller.cache = {
-                    'linux-image-raspi':
-                        make_mock_pkg(
-                            name='linux-image-raspi',
-                            is_installed=True,
-                        )
-                }
-
-                q._test_and_fail_on_armhf_raspi()
-
-                self.assertEqual(
-                    len(controller.abort.mock_calls),
-                    1 if arch == 'armhf' else 0,
-                    f'arch = {arch}',
-                )
-
 
 if __name__ == "__main__":
     import logging
